"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.setAPIAddress = setAPIAddress;
exports.setOAuthAddress = setOAuthAddress;
exports.setScheme = setScheme;
exports.setHttpClient = setHttpClient;
exports.setHttpTimeout = setHttpTimeout;
exports.setToken = setToken;
exports.setAccount = setAccount;
exports.DefaultHttpTimeout = exports.DefaultHttpClient = exports.DefaultUserAgent = exports.DefaultContentType = exports.DefaultScheme = exports.DefaultOAuthAddress = exports.DefaultAPIAddress = exports.SDKVersion = exports.SDKName = void 0;

var pkg = _interopRequireWildcard(require("../package.json"));

var _http = _interopRequireDefault(require("./http"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

// SDKName is the name of the SDK.
var SDKName = pkg.name; // SDKVersion is the current version of the SDK.

exports.SDKName = SDKName;
var SDKVersion = pkg.version; // DefaultAPIAddress is the default address of the Spotinst API.
// It is used e.g. when initializing a new Client without a specific address.

exports.SDKVersion = SDKVersion;
var DefaultAPIAddress = "api.spotinst.io"; // DefaultOAuthAddress is the default address of the Spotinst OAuth API.
// It is used e.g. when initializing a new Client without a specific address.

exports.DefaultAPIAddress = DefaultAPIAddress;
var DefaultOAuthAddress = "oauth.spotinst.io"; // DefaultScheme is the default protocol scheme to use when making HTTP
// calls.

exports.DefaultOAuthAddress = DefaultOAuthAddress;
var DefaultScheme = "https"; // DefaultContentType is the default content type to use when making HTTP
// calls.

exports.DefaultScheme = DefaultScheme;
var DefaultContentType = "application/json"; // DefaultUserAgent is the default user agent to use when making HTTP
// calls.

exports.DefaultContentType = DefaultContentType;
var DefaultUserAgent = SDKName + "/" + SDKVersion; // DefaultHttpClient is the default HTTP client to use when making HTTP calls.

exports.DefaultUserAgent = DefaultUserAgent;
var DefaultHttpClient = new _http["default"](); // DefaultHttpTimeout is the default number of milliseconds to wait for
// a server to send response headers (and start the response body) before
// aborting the request. Defaults to 120 seconds.

exports.DefaultHttpClient = DefaultHttpClient;
var DefaultHttpTimeout = 120 * 1000;
/**
 * setAPIAddress defines the address of the Spotinst API.
 * @param addr
 * @returns {Function}
 */

exports.DefaultHttpTimeout = DefaultHttpTimeout;

function setAPIAddress(addr) {
  return function (config) {
    config.apiAddress = addr;
  };
}
/**
 * setOAuthAddress defines the address of the Spotinst OAuth API.
 * @param addr
 * @returns {Function}
 */


function setOAuthAddress(addr) {
  return function (config) {
    config.oauthAddress = addr;
  };
}
/**
 * setScheme defines the scheme for the address of the Spotinst API.
 * @param scheme
 * @returns {Function}
 */


function setScheme(scheme) {
  return function (config) {
    config.scheme = scheme;
  };
}
/**
 * setHttpClient defines the HTTP client.
 * @param client
 * @returns {Function}
 */


function setHttpClient(client) {
  return function (config) {
    config.httpClient = client;
  };
}
/**
 * setHttpTimeout defines the HTTP timeout.
 * @param msec
 * @returns {Function}
 */


function setHttpTimeout(msec) {
  return function (config) {
    config.httpTimeout = msec;
  };
}
/**
 * setToken defines the authorization token.
 * @param token
 * @returns {Function}
 */


function setToken(token) {
  return function (config) {
    config.credentials = {
      token: token
    };
  };
}
/**
 * setAccount defines the account to operate against.
 * @param accountId
 * @returns {Function}
 */


function setAccount(accountId) {
  return function (config) {
    config.accountId = accountId;
  };
}
/**
 * setUserAgent defines the user agent.
 * @param ua
 * @returns {Function}
 */


function setUserAgent(ua) {
  return function (config) {
    config.userAgent = "".concat(ua, "+").concat(config.userAgent);
  };
}
/**
 * setContentType defines the content type.
 * @param ct
 * @returns {Function}
 */


function setContentType(ct) {
  return function (config) {
    config.contentType = ct;
  };
}