"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _config = require("../config");

var _util = _interopRequireDefault(require("../util"));

var _debug = _interopRequireDefault(require("debug"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

var AwsGroupRollService = /*#__PURE__*/function () {
  function AwsGroupRollService(client) {
    _classCallCheck(this, AwsGroupRollService);

    this._debug = (0, _debug["default"])("".concat(_config.SDKName, ":aws_group_roll"));
    this._client = client;
    this._basePath = "/aws/ec2/group";
  }
  /**
   * list describes all the rolling deployments.
   * @param params
   * @returns {Promise}
   */


  _createClass(AwsGroupRollService, [{
    key: "list",
    value: function list() {
      var _this = this;

      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      var callback = arguments.length > 1 ? arguments[1] : undefined;
      return new Promise(function (resolve, reject) {
        if (!_util["default"].isValid("groupId", params.groupId, callback, reject)) return;

        _this._debug("initiating a new list rolls request");

        var req = _this._client._newRequest("GET", "".concat(_this._basePath, "/").concat(params.groupId, "/roll"));

        _this._debug("making list rolls request");

        _this._client._requireOK(_this._client._doRequest(req)).then(function (res) {
          _this._debug("promise resolved");

          _util["default"].resolveOnSuccess(res.response.items, callback, resolve);
        })["catch"](function (err) {
          _this._debug("promise rejected", err);

          _util["default"].rejectOnFailure(err.toString(), callback, reject);
        });
      });
    }
    /**
     * read describes a specific rolling deployment.
     * @param params
     * @returns {Promise}
     */

  }, {
    key: "read",
    value: function read() {
      var _this2 = this;

      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      var callback = arguments.length > 1 ? arguments[1] : undefined;
      return new Promise(function (resolve, reject) {
        if (!_util["default"].isValid("groupId", params.groupId, callback, reject)) return;
        if (!_util["default"].isValid("rollId", params.rollId, callback, reject)) return;

        _this2._debug("initiating a new read roll request, id=", params.id);

        var req = _this2._client._newRequest("GET", "".concat(_this2._basePath, "/").concat(params.groupId, "/roll/").concat(params.rollId));

        _this2._debug("making read roll request");

        _this2._client._requireOK(_this2._client._doRequest(req)).then(function (res) {
          _this2._debug("promise resolved");

          _util["default"].resolveOnSuccess(res.response.items, callback, resolve);
        })["catch"](function (err) {
          _this2._debug("promise rejected", err);

          _util["default"].rejectOnFailure(err.toString(), callback, reject);
        });
      });
    }
    /**
     * start starts a new rolling deployment.
     * @param params
     * @returns {Promise}
     */

  }, {
    key: "start",
    value: function start() {
      var _this3 = this;

      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      var callback = arguments.length > 1 ? arguments[1] : undefined;
      return new Promise(function (resolve, reject) {
        if (!_util["default"].isValid("groupId", params.groupId, callback, reject)) return;
        if (!_util["default"].isValid("rollId", params.rollId, callback, reject)) return;

        _this3._debug("initiating a new start roll request, id=", params.id);

        var req = _this3._client._newRequest("PUT", "".concat(_this3._basePath, "/").concat(params.groupId, "/roll"));

        _this3._debug("making start roll request");

        _this3._client._requireOK(_this3._client._doRequest(req)).then(function (res) {
          _this3._debug("promise resolved");

          _util["default"].resolveOnSuccess(res.response.items, callback, resolve);
        })["catch"](function (err) {
          _this3._debug("promise rejected", err);

          _util["default"].rejectOnFailure(err.toString(), callback, reject);
        });
      });
    }
    /**
     * stop stops an existing rolling deployment.
     * @param params
     * @returns {Promise}
     */

  }, {
    key: "stop",
    value: function stop() {
      var _this4 = this;

      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      var callback = arguments.length > 1 ? arguments[1] : undefined;
      return new Promise(function (resolve, reject) {
        if (!_util["default"].isValid("groupId", params.groupId, callback, reject)) return;
        if (!_util["default"].isValid("rollId", params.rollId, callback, reject)) return;

        _this4._debug("initiating a new stop roll request, id=", params.id);

        var req = _this4._client._newRequest("PUT", "".concat(_this4._basePath, "/").concat(params.groupId, "/roll/").concat(params.rollId));

        _this4._debug("making stop roll request");

        _this4._client._requireOK(_this4._client._doRequest(req)).then(function (res) {
          _this4._debug("promise resolved");

          _util["default"].resolveOnSuccess(res.response.items, callback, resolve);
        })["catch"](function (err) {
          _this4._debug("promise rejected", err);

          _util["default"].rejectOnFailure(err.toString(), callback, reject);
        });
      });
    }
  }]);

  return AwsGroupRollService;
}();

exports["default"] = AwsGroupRollService;