"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _config = require("../../config");

var _util = _interopRequireDefault(require("../../util"));

var _debug = _interopRequireDefault(require("debug"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

var PatternService = /*#__PURE__*/function () {
  function PatternService(client) {
    _classCallCheck(this, PatternService);

    this._debug = (0, _debug["default"])("".concat(_config.SDKName, ":endpoint:pattern"));
    this._client = client;
    this._basePath = "/functions/pattern";
  }
  /**
   * read describes a specific endpoint.
   * @param params
   * @returns {Promise}
   */


  _createClass(PatternService, [{
    key: "read",
    value: function read() {
      var _this = this;

      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      var callback = arguments.length > 1 ? arguments[1] : undefined;
      return new Promise(function (resolve, reject) {
        _this._debug("initiating a new read endpoint request, id=", params.resourceId);

        var url = "".concat(_this._basePath, "/").concat(params.patternId, "?accountId=").concat(params.accountId);

        var req = _this._client._newRequest("GET", url);

        _this._debug("making read endpoint request");

        _this._client._requireOK(_this._client._doRequest(req)).then(function (res) {
          _this._debug("promise resolved");

          _util["default"].resolveOnSuccess(res.response.items, callback, resolve);
        })["catch"](function (err) {
          _this._debug("promise rejected", err);

          _util["default"].rejectOnFailure(err.toString(), callback, reject);
        });
      });
    }
    /**
     * list describes a list of endpoints.
     * @param params
     * @returns {Promise}
     */

  }, {
    key: "list",
    value: function list() {
      var _this2 = this;

      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      var callback = arguments.length > 1 ? arguments[1] : undefined;
      return new Promise(function (resolve, reject) {
        _this2._debug("initiating a new list endpoints request");

        var url = "".concat(_this2._basePath, "?accountId=").concat(params.accountId, "&environmentId=").concat(params.environmentId);

        var req = _this2._client._newRequest("GET", url);

        _this2._debug("making list endpoints request");

        _this2._client._requireOK(_this2._client._doRequest(req)).then(function (res) {
          _this2._debug("promise resolved");

          _util["default"].resolveOnSuccess(res.response.items, callback, resolve);
        })["catch"](function (err) {
          _this2._debug("promise rejected", err);

          _util["default"].rejectOnFailure(err.toString(), callback, reject);
        });
      });
    }
    /**
     * create a new endpoint.
     * @param params
     * @returns {Promise}
     */

  }, {
    key: "create",
    value: function create() {
      var _this3 = this;

      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      var callback = arguments.length > 1 ? arguments[1] : undefined;
      return new Promise(function (resolve, reject) {
        _this3._debug("initiating a new create endpoint request, params=", params);

        _this3._debug("preparing body");

        var body = {
          pattern: Object.assign({}, params)
        };

        _this3._debug("body=", body);

        var req = _this3._client._newRequest("POST", "".concat(_this3._basePath, "?accountId=").concat(params.accountId), body);

        _this3._debug("making create endpoint request");

        _this3._client._requireOK(_this3._client._doRequest(req)).then(function (res) {
          _this3._debug("promise resolved");

          _util["default"].resolveOnSuccess(res.response.items[0], callback, resolve);
        })["catch"](function (err) {
          _this3._debug("promise rejected", err);

          _util["default"].rejectOnFailure(err.toString(), callback, reject);
        });
      });
    }
    /**
     * update an existing endpoint.
     * @param params
     * @returns {Promise}
     */

  }, {
    key: "update",
    value: function update() {
      var _this4 = this;

      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      var callback = arguments.length > 1 ? arguments[1] : undefined;
      return new Promise(function (resolve, reject) {
        _this4._debug("initiating a new update endpoint request, id=", params.id);

        _this4._debug("preparing body");

        var body = {
          pattern: Object.assign({}, params)
        };

        _this4._debug("body=", body);

        delete body.pattern.accountId;
        delete body.pattern.environmentId;
        delete body.pattern.id;

        var req = _this4._client._newRequest("PUT", "".concat(_this4._basePath, "/").concat(params.id, "?accountId=").concat(params.accountId), body);

        _this4._debug("making update endpoint request");

        _this4._client._requireOK(_this4._client._doRequest(req)).then(function (res) {
          _this4._debug("promise resolved");

          _util["default"].resolveOnSuccess(res.response.items, callback, resolve);
        })["catch"](function (err) {
          _this4._debug("promise rejected", err);

          _util["default"].rejectOnFailure(err.toString(), callback, reject);
        });
      });
    }
    /**
     * delete an existing endpoint.
     * @param params
     * @returns {Promise}
     */

  }, {
    key: "delete",
    value: function _delete() {
      var _this5 = this;

      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      var callback = arguments.length > 1 ? arguments[1] : undefined;
      return new Promise(function (resolve, reject) {
        if (!_util["default"].isValid("id", params.id, callback, reject)) return;

        _this5._debug("initiating a new delete request, id=", params.id);

        var req = _this5._client._newRequest("DELETE", "".concat(_this5._basePath, "/").concat(params.id, "?accountId=").concat(params.accountId));

        _this5._debug("making delete endpoint request");

        _this5._client._requireOK(_this5._client._doRequest(req)).then(function (res) {
          _this5._debug("promise resolved");

          _util["default"].resolveOnSuccess(res.response.items, callback, resolve);
        })["catch"](function (err) {
          _this5._debug("promise rejected", err);

          _util["default"].rejectOnFailure(err.toString(), callback, reject);
        });
      });
    }
  }]);

  return PatternService;
}();

exports["default"] = PatternService;