"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _config = require("../config");

var _util = _interopRequireDefault(require("../util"));

var _debug = _interopRequireDefault(require("debug"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

var FunctionsService = /*#__PURE__*/function () {
  function FunctionsService(client) {
    _classCallCheck(this, FunctionsService);

    this._debug = (0, _debug["default"])("".concat(_config.SDKName, ":functions"));
    this._client = client;
    this._basePath = "/functions/function";
  }
  /**
   * read describes a specific function.
   * @param params
   * @returns {Promise}
   */


  _createClass(FunctionsService, [{
    key: "read",
    value: function read() {
      var _this = this;

      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      var callback = arguments.length > 1 ? arguments[1] : undefined;
      return new Promise(function (resolve, reject) {
        _this._debug("initiating a new read function request, id=", params.id);

        if (!_util["default"].isValid("id", params.id, callback, reject)) return;
        var url = "".concat(_this._basePath, "/").concat(params.id, "?environmentId=").concat(params.environmentId, "&accountId=").concat(params.accountId);

        var req = _this._client._newRequest("GET", url);

        _this._debug("making read function request");

        _this._client._requireOK(_this._client._doRequest(req)).then(function (res) {
          _this._debug("promise resolved");

          _util["default"].resolveOnSuccess(res.response.items, callback, resolve);
        })["catch"](function (err) {
          _this._debug("promise rejected", err);

          _util["default"].rejectOnFailure(err.toString(), callback, reject);
        });
      });
    }
    /**
     * list describes a list of functions.
     * @param params
     * @returns {Promise}
     */

  }, {
    key: "list",
    value: function list() {
      var _this2 = this;

      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      var callback = arguments.length > 1 ? arguments[1] : undefined;
      return new Promise(function (resolve, reject) {
        _this2._debug("initiating a new list functions request");

        var url = "".concat(_this2._basePath, "?environmentId=").concat(params.environmentId, "&accountId=").concat(params.accountId);

        var req = _this2._client._newRequest("GET", url);

        _this2._debug("making list functions request");

        _this2._client._requireOK(_this2._client._doRequest(req)).then(function (res) {
          _this2._debug("promise resolved");

          _util["default"].resolveOnSuccess(res.response.items, callback, resolve);
        })["catch"](function (err) {
          _this2._debug("promise rejected", err);

          _util["default"].rejectOnFailure(err.toString(), callback, reject);
        });
      });
    }
    /**
     * create a function.
     * @param params
     * @returns {Promise}
     */

  }, {
    key: "create",
    value: function create() {
      var _this3 = this;

      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      var callback = arguments.length > 1 ? arguments[1] : undefined;
      return new Promise(function (resolve, reject) {
        _this3._debug("initiating a new create function request, params=", params);

        _this3._debug("preparing body");

        var body = Object.assign({}, params);

        _this3._debug("body=", body);

        var req = _this3._client._newRequest("POST", "".concat(_this3._basePath, "?accountId=").concat(body["function"].accountId), body);

        _this3._debug("making create function request");

        _this3._client._requireOK(_this3._client._doRequest(req)).then(function (res) {
          _this3._debug("promise resolved");

          _util["default"].resolveOnSuccess(res.response.items[0], callback, resolve);
        })["catch"](function (err) {
          _this3._debug("promise rejected", err);

          _util["default"].rejectOnFailure(err.toString(), callback, reject);
        });
      });
    }
    /**
     * update an existing function.
     * @param params
     * @returns {Promise}
     */

  }, {
    key: "update",
    value: function update() {
      var _this4 = this;

      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      var callback = arguments.length > 1 ? arguments[1] : undefined;
      return new Promise(function (resolve, reject) {
        if (!params["function"]) {
          params = {
            "function": _objectSpread({}, params)
          };
        }

        _this4._debug("initiating a new update function request, id=", params["function"].id);

        _this4._debug("preparing body");

        var body = {
          "function": Object.assign({}, params["function"])
        };
        delete body["function"].id;

        _this4._debug("body=", body);

        var req = _this4._client._newRequest("PUT", "".concat(_this4._basePath, "/").concat(params["function"].id, "?accountId=").concat(body["function"].accountId), body);

        _this4._debug("making update function request");

        _this4._client._requireOK(_this4._client._doRequest(req)).then(function (res) {
          _this4._debug("promise resolved");

          _util["default"].resolveOnSuccess(res.response.items, callback, resolve);
        })["catch"](function (err) {
          _this4._debug("promise rejected", err);

          _util["default"].rejectOnFailure(err.toString(), callback, reject);
        });
      });
    }
    /**
     * delete an existing function.
     * @param params
     * @returns {Promise}
     */

  }, {
    key: "delete",
    value: function _delete() {
      var _this5 = this;

      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      var callback = arguments.length > 1 ? arguments[1] : undefined;
      return new Promise(function (resolve, reject) {
        if (!_util["default"].isValid("id", params.id, callback, reject)) return;

        _this5._debug("initiating a new delete function request, id=", params.id);

        var req = _this5._client._newRequest("DELETE", "".concat(_this5._basePath, "/").concat(params.id, "?accountId=").concat(params.accountId));

        _this5._debug("making delete function request");

        _this5._client._requireOK(_this5._client._doRequest(req)).then(function (res) {
          _this5._debug("promise resolved");

          _util["default"].resolveOnSuccess(res.response.items, callback, resolve);
        })["catch"](function (err) {
          _this5._debug("promise rejected", err);

          _util["default"].rejectOnFailure(err.toString(), callback, reject);
        });
      });
    }
    /**
     * getting logs of afunction.
     * @param params
     * @returns {Promise}
     */

  }, {
    key: "logs",
    value: function logs() {
      var _this6 = this;

      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      var callback = arguments.length > 1 ? arguments[1] : undefined;
      return new Promise(function (resolve, reject) {
        var startTime;
        var body = {
          "function": Object.assign({}, params["function"])
        };
        if (!_util["default"].isValid("functionId", body["function"].functionId, callback, reject)) return;

        if (body["function"].startTime && body["function"].startTime instanceof Date) {
          startTime = body["function"].startTime;
        } else {
          startTime = new Date(Date.now() - 5 * 60000);
        }

        _this6._debug("initiating get function logs request. id=", body["function"].functionId);

        var req = _this6._client._newRequest("GET", "".concat(_this6._basePath, "/log?from=").concat(startTime.getTime(), "&to=").concat(Date.now(), "&accountId=").concat(body["function"].accountId, "&functionId=").concat(body["function"].functionId));

        _this6._debug("making get function logs request");

        _this6._client._requireOK(_this6._client._doRequest(req)).then(function (res) {
          _this6._debug("promise resolved");

          _util["default"].resolveOnSuccess(res.response.items, callback, resolve);
        })["catch"](function (err) {
          _this6._debug("promise rejected", err);

          _util["default"].rejectOnFailure(err.toString(), callback, reject);
        });
      });
    }
  }]);

  return FunctionsService;
}();

exports["default"] = FunctionsService;